contentPadding property
Content padding inside the card. Defaults to 16 pixels on all sides. Note: If content is null, this padding will not be applied.
Implementation
final EdgeInsets contentPadding;
Content padding inside the card. Defaults to 16 pixels on all sides. Note: If content is null, this padding will not be applied.
final EdgeInsets contentPadding;