DialogAction class
Represents a dialog action with label, icon, and callback
Constructors
- DialogAction({required String label, required VoidCallback onAction, IconData? icon, bool isPrimary = false, bool disabled = false})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited