VList class
A grouped container for organizing multiple widgets with an optional label, description, and footer.
VList wraps a list of children and displays them inside a styled card container, optionally with a header label, description, and footer. Dividers between items are controlled via the divider property. Set transparent to remove the card background.
Example
VList(
label: 'Connected Devices',
description: 'Active devices in your network',
footer: 'Last updated just now',
children: [
VListItem(
title: Text('Router'),
prefix: Icon(Icons.router),
),
VListItem(
title: Text('Printer'),
prefix: Icon(Icons.print),
),
],
)
- Inheritance
Constructors
Properties
-
children
→ List<
Widget> -
final
- description → dynamic
-
final
- divider → VListDivider
-
final
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → dynamic
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transparent → bool
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited