height property

double height
final

Maximum height of the entire table widget in logical pixels.

The table will shrink to fit its content if the content is shorter than this value. The header row height is calculated dynamically based on density padding.

Implementation

final double height;